@@ -11,7 +11,12 @@ pub mod peer;
 pub mod stats;
 pub mod util;
 
+pub use ::data as webrtc_data;
+pub use ::media as webrtc_media;
 pub use error::Error;
+pub use interceptor;
+pub use rtcp;
+pub use rtp;
 
 #[macro_use]
 extern crate lazy_static;
