@@ -3,7 +3,7 @@ use std::fmt;
 /// ICECredentialType indicates the type of credentials used to connect to
 /// an ICE server.
 #[derive(Debug, Copy, Clone, PartialEq)]
-pub enum ICECredentialType {
+pub enum RTCIceCredentialType {
     Unspecified,
 
     /// ICECredential::Password describes username and password based
@@ -16,30 +16,30 @@ pub enum ICECredentialType {
     Oauth,
 }
 
-impl Default for ICECredentialType {
+impl Default for RTCIceCredentialType {
     fn default() -> Self {
-        ICECredentialType::Password
+        RTCIceCredentialType::Password
     }
 }
 
 const ICE_CREDENTIAL_TYPE_PASSWORD_STR: &str = "password";
 const ICE_CREDENTIAL_TYPE_OAUTH_STR: &str = "oauth";
 
-impl From<&str> for ICECredentialType {
+impl From<&str> for RTCIceCredentialType {
     fn from(raw: &str) -> Self {
         match raw {
-            ICE_CREDENTIAL_TYPE_PASSWORD_STR => ICECredentialType::Password,
-            ICE_CREDENTIAL_TYPE_OAUTH_STR => ICECredentialType::Oauth,
-            _ => ICECredentialType::Unspecified,
+            ICE_CREDENTIAL_TYPE_PASSWORD_STR => RTCIceCredentialType::Password,
+            ICE_CREDENTIAL_TYPE_OAUTH_STR => RTCIceCredentialType::Oauth,
+            _ => RTCIceCredentialType::Unspecified,
         }
     }
 }
 
-impl fmt::Display for ICECredentialType {
+impl fmt::Display for RTCIceCredentialType {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
-            ICECredentialType::Password => write!(f, "{}", ICE_CREDENTIAL_TYPE_PASSWORD_STR),
-            ICECredentialType::Oauth => write!(f, "{}", ICE_CREDENTIAL_TYPE_OAUTH_STR),
+            RTCIceCredentialType::Password => write!(f, "{}", ICE_CREDENTIAL_TYPE_PASSWORD_STR),
+            RTCIceCredentialType::Oauth => write!(f, "{}", ICE_CREDENTIAL_TYPE_OAUTH_STR),
             _ => write!(f, "{}", crate::UNSPECIFIED_STR),
         }
     }
@@ -52,22 +52,22 @@ mod test {
     #[test]
     fn test_new_ice_credential_type() {
         let tests = vec![
-            ("Unspecified", ICECredentialType::Unspecified),
-            ("password", ICECredentialType::Password),
-            ("oauth", ICECredentialType::Oauth),
+            ("Unspecified", RTCIceCredentialType::Unspecified),
+            ("password", RTCIceCredentialType::Password),
+            ("oauth", RTCIceCredentialType::Oauth),
         ];
 
         for (ct_str, expected_ct) in tests {
-            assert_eq!(expected_ct, ICECredentialType::from(ct_str));
+            assert_eq!(expected_ct, RTCIceCredentialType::from(ct_str));
         }
     }
 
     #[test]
     fn test_ice_credential_type_string() {
         let tests = vec![
-            (ICECredentialType::Unspecified, "Unspecified"),
-            (ICECredentialType::Password, "password"),
-            (ICECredentialType::Oauth, "oauth"),
+            (RTCIceCredentialType::Unspecified, "Unspecified"),
+            (RTCIceCredentialType::Password, "password"),
+            (RTCIceCredentialType::Oauth, "oauth"),
         ];
 
         for (ct, expected_string) in tests {
